Integration weights
===================

Uploading the weights
---------------------

Complex integration weight functions can be uploaded to the device by using 
``write_integration_weights``.

The uploading and data format is explained in more detail in :ref:`csv_upload`

Viewing the weight functions
----------------------------

Weight functions can be viewed in Labber scope window.
